# 異なるバージョンの互換性

この実験は古いバージョンのOpenSesameで作成されました。

このことにより問題は発生しません。 しかし、安全のために実験を別名で保存することをおすすめします。

実験ファイルの操作:?

[実験を保存する](opensesame://action.save){: .important-button} <br />
[OpenSesame 3 での変更点](new:html://osdoc.cogsci.nl/3.2/important-changes-3/){: .button} <br />

もしくは:

[今後このメッセージを表示しない](opensesame://event.os3n_dismiss_old_experiment){: .dismiss-button}
